@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "consult-notmuch" "1.1.0"
+(define-package "consult-notmuch" "20250815.1739"
   "Notmuch search using consult."
   '((emacs   "28.1")
     (consult "2.7")
